pub struct ScopePath(pub Vec<ScopeId>);Expand description
Full scope chain from the current scope up to the first-without-parent — useful for devtools or hierarchical lookups that bypass inject.
Tuple Fields
0: Vec<ScopeId>Trait Implementations
Sourceimpl<'a> From<LifecycleContext<'a>> for ScopePath
impl<'a> From<LifecycleContext<'a>> for ScopePath
Sourcefn from(ctx: LifecycleContext<'a>) -> Self
fn from(ctx: LifecycleContext<'a>) -> Self
Converts to this type from the input type.