pub struct AppBootFailed {
pub reason: &'static str,
}Expand description
Emitted when app boot fails after plugin validation succeeds.
reason is a stable identifier from a closed set of &'static str
values produced by the runtime: "component_registry",
"missing_window", "missing_document", "missing_pp_app_root".
Fields
reason: &'static strTrait Implementations
Sourceimpl Clone for AppBootFailed
impl Clone for AppBootFailed
Sourcefn clone(&self) -> AppBootFailed
fn clone(&self) -> AppBootFailed
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AppBootFailed