pub struct ServerFunctionClientStarted {
pub route: String,
}Expand description
Emitted before the browser client sends a generated #[server]
function request.
route is the public request path with any query string or fragment
stripped. Request arguments and response bodies are never included.
Fields
route: StringTrait Implementations
Sourceimpl Clone for ServerFunctionClientStarted
impl Clone for ServerFunctionClientStarted
Sourcefn clone(&self) -> ServerFunctionClientStarted
fn clone(&self) -> ServerFunctionClientStarted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ServerFunctionClientStarted
impl RefUnwindSafe for ServerFunctionClientStarted
impl Send for ServerFunctionClientStarted
impl Sync for ServerFunctionClientStarted
impl Unpin for ServerFunctionClientStarted
impl UnsafeUnpin for ServerFunctionClientStarted
impl UnwindSafe for ServerFunctionClientStarted